@@ -1,7 +1,7 @@
 import React, { FC, useEffect, useState } from 'react';
 import { connect } from 'react-redux';
 
-import { config, featureEnabled, reportExperimentView } from '@grafana/runtime';
+import { config, featureEnabled, reportExperimentView, reportInteraction } from '@grafana/runtime';
 import { Drawer, ToolbarButton, useTheme2 } from '@grafana/ui';
 import { UpgradeBox, UpgradeContentVertical } from 'app/core/components/Upgrade/UpgradeBox';
 import { contextSrv } from 'app/core/core';
@@ -48,6 +48,7 @@ const AnalyticsContent: FC<AnalyticsContentProps> = ({ dashboard, isDrawerOpen,
         <AnalyticsToolbarButton
           onClick={() => {
             setDrawerOpen(true);
+            reportInteraction('dashboards_toolbar_actions_clicked', { item: 'insights' });
           }}
           isHighlighted={showHighlight}
         />
