@@ -1,15 +1,13 @@
 import { fireEvent, render, screen, waitFor } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
 import React from 'react';
-import { Provider } from 'react-redux';
-import { Router } from 'react-router-dom';
+import { TestProvider } from 'test/helpers/TestProvider';
 import { selectOptionInTest } from 'test/helpers/selectOptionInTest';
 
-import { locationService } from '@grafana/runtime';
 import { getRouteComponentProps } from 'app/core/navigation/__mocks__/routeProps';
 
 import { mockToolkitActionCreator } from '../../../../test/core/redux/mocks';
-import { addRootReducer, configureStore } from '../../../store/configureStore';
+import { addRootReducer } from '../../../store/configureStore';
 import { SchedulingFrequency } from '../../types';
 import reportsReducers, { initialState, updateReportProp } from '../state/reducers';
 
@@ -29,7 +27,16 @@ jest.mock('app/core/services/backend_srv', () => {
 
 jest.mock('@grafana/runtime/src/config', () => ({
   config: {
-    buildInfo: {},
+    ...jest.requireActual('@grafana/runtime/src/config').config,
+    buildInfo: {
+      edition: 'Enterprise',
+      version: '9.0.0',
+      commit: 'abc123',
+      env: 'dev',
+      latestVersion: '',
+      hasUpdate: false,
+      hideVersion: false,
+    },
     licenseInfo: {
       enabledFeatures: { 'reports.email': true },
     },
@@ -62,7 +69,6 @@ const testReport = {
 
 const setup = (propOverrides?: Partial<Props>) => {
   addRootReducer(reportsReducers);
-  const store = configureStore();
   const props: Props = {
     ...getRouteComponentProps(),
     report: blankReport,
@@ -71,11 +77,9 @@ const setup = (propOverrides?: Partial<Props>) => {
   };
 
   return render(
-    <Provider store={store}>
-      <Router history={locationService.getHistory()}>
-        <Schedule {...props} />
-      </Router>
-    </Provider>
+    <TestProvider>
+      <Schedule {...props} />
+    </TestProvider>
   );
 };
 
@@ -206,7 +210,7 @@ describe('Report Scheduling', () => {
       expect(screen.queryByText(/end time/i)).not.toBeInTheDocument();
       expect(
         screen.getByText(
-          /The report will be sent: Monthly on 1st day at 00:00 UTC-05:00, January 1, 2020 - January 11, 2020./i
+          /The report will be sent: Monthly on the 1st day at 00:00 UTC-05:00, January 1, 2020 - January 11, 2020./i
         )
       ).toBeInTheDocument();
       fireEvent.click(screen.getByRole('checkbox', { name: /send on the last day of month/i }));
